# Note: this file has been initially generated by Module::Build::Convert 0.49

use strict;
use warnings;
use 5.9.5;

use Module::Build;

my $build = Module::Build->new
  (
   module_name => 'Data::PrintUtils',
   dist_author => 'q{Robert Haxton <robert.haxton@gmail.com>}',
   dist_version_from => 'lib/Data/PrintUtils.pm',
   requires => {
                 'Data::Dumper' => 0,
                 'Getopt::CommandLineExports' => 0,
                 'HTML::Tabulate' => 0,
                 'Test::More' => 0,
                 'Test::Output' => 0,
                 'Time::HiRes' => 0,
                 'XML::Simple' => 0,
                 },
   add_to_cleanup => [
                       'Data-PrintUtils-*',
                       ],                       
   license => 'unknown',
   create_readme => 1,
   create_makefile_pl => 'traditional',
  );

$build->create_build_script;
